@@ -1,12 +1,16 @@
-import { ApolloClient, InMemoryCache, ApolloProvider } from "@apollo/client";
+import { ApolloClient, InMemoryCache, HttpLink } from "@apollo/client/core";
+import { Defer20220824Handler } from "@apollo/client/incremental";
+import { ApolloProvider } from "@apollo/client/react";
 import ApolloTests from "@/components/apollo-tests";
 import { RelayEnvironmentProvider } from "react-relay";
 import RelayTests from "./components/relay-tests";
 import { RelayEnvironment } from "./RelayEnvironment";
 
 const client = new ApolloClient({
-	uri: "http://localhost:8000/graphql",
+	link: new HttpLink({ uri: "http://localhost:8000/graphql" }),
 	cache: new InMemoryCache(),
+	// Enable @defer support with the 2022-08-24 defer spec
+	incrementalHandler: new Defer20220824Handler(),
 });
 
 function App() {
