@@ -19,7 +19,6 @@ GQL_CORE_VERSIONS = [
 COMMON_PYTEST_OPTIONS = [
     "--cov=.",
     "--cov-append",
-    "--cov-report=xml",
     "-n",
     "auto",
     "--showlocals",
@@ -60,7 +59,7 @@ def with_gql_core_parametrize(name: str, params: list[str]) -> Callable[[Any], A
     arg_names = f"{name}, gql_core"
     combinations = list(itertools.product(params, GQL_CORE_VERSIONS))
     ids = [f"{name}-{comb[0]}__graphql-core-{comb[1]}" for comb in combinations]
-    return lambda fn: nox.parametrize(arg_names, combinations, ids=ids)(fn)
+    return nox.parametrize(arg_names, combinations, ids=ids)
 
 
 @session(python=PYTHON_VERSIONS, name="Tests", tags=["tests"])
@@ -145,7 +144,6 @@ def test_pydantic(session: Session, gql_core: str) -> None:
         "pytest",
         "--cov=.",
         "--cov-append",
-        "--cov-report=xml",
         "-m",
         "pydantic",
         "--ignore=tests/cli",
@@ -158,13 +156,12 @@ def test_pydantic(session: Session, gql_core: str) -> None:
 def test_pydantic_v2(session: Session, gql_core: str) -> None:
     session.run_always("poetry", "install", "--without=integrations", external=True)
 
-    session._session.install("pydantic~=2.12")  # type: ignore
+    session._session.install("pydantic>=2.2")  # type: ignore
     _install_gql_core(session, gql_core)
     session.run(
         "pytest",
         "--cov=.",
         "--cov-append",
-        "--cov-report=xml",
         "-m",
         "pydantic",
         "--ignore=tests/cli",
@@ -179,12 +176,12 @@ def tests_typecheckers(session: Session) -> None:
     session.install("pyright")
     session.install("pydantic")
     session.install("mypy")
+    session.install("ty")
 
     session.run(
         "pytest",
         "--cov=.",
         "--cov-append",
-        "--cov-report=xml",
         "tests/typecheckers",
         "-vv",
     )
@@ -201,7 +198,6 @@ def tests_cli(session: Session) -> None:
         "pytest",
         "--cov=.",
         "--cov-append",
-        "--cov-report=xml",
         "tests/cli",
         "-vv",
     )
