@@ -87,3 +87,48 @@ def test_can_use_both_pydantic_1_and_2():
 
     assert not result.errors
     assert result.data == {"user": {"__typename": "LegacyUser", "name": "legacy"}}
+
+
+@pytest.mark.skipif(
+    sys.version_info >= (3, 14),
+    reason="Pydantic v1 is not compatible with Python 3.14+",
+)
+@needs_pydantic_v2
+def test_can_use_nested_pydantic_v1_models():
+    from pydantic import v1 as pydantic_v1
+
+    class Book(pydantic_v1.BaseModel):
+        title: str
+
+    class Library(pydantic_v1.BaseModel):
+        books: list[Book]
+
+    @strawberry.experimental.pydantic.type(model=Book, all_fields=True)
+    class BookType:
+        pass
+
+    @strawberry.experimental.pydantic.type(model=Library, all_fields=True)
+    class LibraryType:
+        pass
+
+    @strawberry.type
+    class Query:
+        library: LibraryType
+
+    schema = strawberry.Schema(query=Query)
+
+    expected_schema = """
+    type BookType {
+      title: String!
+    }
+
+    type LibraryType {
+      books: [BookType!]!
+    }
+
+    type Query {
+      library: LibraryType!
+    }
+    """
+
+    assert str(schema) == textwrap.dedent(expected_schema).strip()
