@@ -67,7 +67,6 @@ class AsgiHttpClient(HttpClient):
     def __init__(
         self,
         schema: Schema,
-        graphiql: bool | None = None,
         graphql_ide: GraphQL_IDE | None = "graphiql",
         allow_queries_via_get: bool = True,
         keep_alive: bool = False,
@@ -82,7 +81,6 @@ class AsgiHttpClient(HttpClient):
     ):
         view = GraphQLView(
             schema,
-            graphiql=graphiql,
             graphql_ide=graphql_ide,
             allow_queries_via_get=allow_queries_via_get,
             keep_alive=keep_alive,
