@@ -44,7 +44,6 @@ class AsyncDjangoHttpClient(DjangoHttpClient):
     def __init__(
         self,
         schema: Schema,
-        graphiql: bool | None = None,
         graphql_ide: GraphQL_IDE | None = "graphiql",
         allow_queries_via_get: bool = True,
         result_override: ResultOverrideFunction = None,
@@ -52,7 +51,6 @@ class AsyncDjangoHttpClient(DjangoHttpClient):
     ):
         self.view = AsyncGraphQLView.as_view(
             schema=schema,
-            graphiql=graphiql,
             graphql_ide=graphql_ide,
             allow_queries_via_get=allow_queries_via_get,
             result_override=result_override,
