@@ -50,7 +50,6 @@ class AsyncFlaskHttpClient(FlaskHttpClient):
     def __init__(
         self,
         schema: Schema,
-        graphiql: bool | None = None,
         graphql_ide: GraphQL_IDE | None = "graphiql",
         allow_queries_via_get: bool = True,
         result_override: ResultOverrideFunction = None,
@@ -62,7 +61,6 @@ class AsyncFlaskHttpClient(FlaskHttpClient):
         view = GraphQLView.as_view(
             "graphql_view",
             schema=schema,
-            graphiql=graphiql,
             graphql_ide=graphql_ide,
             allow_queries_via_get=allow_queries_via_get,
             result_override=result_override,
