@@ -53,7 +53,6 @@ class LitestarHttpClient(HttpClient):
     def __init__(
         self,
         schema: Schema,
-        graphiql: bool | None = None,
         graphql_ide: GraphQL_IDE | None = "graphiql",
         allow_queries_via_get: bool = True,
         keep_alive: bool = False,
@@ -69,7 +68,6 @@ class LitestarHttpClient(HttpClient):
     ):
         BaseGraphQLController = make_graphql_controller(
             schema=schema,
-            graphiql=graphiql,
             graphql_ide=graphql_ide,
             allow_queries_via_get=allow_queries_via_get,
             keep_alive=keep_alive,
