@@ -88,7 +88,6 @@ class QuartHttpClient(HttpClient):
     def __init__(
         self,
         schema: Schema,
-        graphiql: bool | None = None,
         graphql_ide: GraphQL_IDE | None = "graphiql",
         allow_queries_via_get: bool = True,
         keep_alive: bool = False,
@@ -107,7 +106,6 @@ class QuartHttpClient(HttpClient):
         view = GraphQLView.as_view(
             "graphql_view",
             schema=schema,
-            graphiql=graphiql,
             graphql_ide=graphql_ide,
             allow_queries_via_get=allow_queries_via_get,
             result_override=result_override,
