@@ -572,19 +572,6 @@ def test_name_first_directive_value():
     assert result.data["greeting"] == "Hi Bar"
 
 
-def test_named_based_directive_value_is_deprecated():
-    with pytest.deprecated_call(match=r"Argument name-based matching of 'value'"):
-
-        @strawberry.type
-        class Query:
-            hello: str = "hello"
-
-        @strawberry.directive(locations=[DirectiveLocation.FIELD])
-        def deprecated_value(value): ...
-
-        strawberry.Schema(query=Query, directives=[deprecated_value])
-
-
 @pytest.mark.asyncio
 async def test_directive_list_argument() -> NoReturn:
     @strawberry.type
