@@ -1,6 +1,6 @@
 import textwrap
 from enum import Enum
-from typing import Any, Generic, Optional, TypeVar, Union
+from typing import Any, Generic, TypeVar
 from typing_extensions import Self
 
 import strawberry
@@ -291,7 +291,7 @@ def test_supports_optional():
 
     @strawberry.type
     class Edge(Generic[T]):
-        node: Optional[T] = None
+        node: T | None = None
 
     @strawberry.type
     class Query:
@@ -359,7 +359,7 @@ def test_supports_lists_of_optionals():
 
     @strawberry.type
     class Edge(Generic[T]):
-        nodes: list[Optional[T]]
+        nodes: list[T | None]
 
     @strawberry.type
     class Query:
@@ -453,7 +453,7 @@ def test_supports_generic_in_unions():
     @strawberry.type
     class Query:
         @strawberry.field
-        def example(self) -> Union[Fallback, Edge[int]]:
+        def example(self) -> Fallback | Edge[int]:
             return Edge(cursor=strawberry.ID("1"), node=1)
 
     schema = strawberry.Schema(query=Query)
@@ -496,7 +496,7 @@ def test_generic_with_enum_as_param_of_type_inside_unions():
     @strawberry.type
     class Query:
         @strawberry.field
-        def result(self) -> Union[Pet, ErrorNode[Codes]]:
+        def result(self) -> Pet | ErrorNode[Codes]:
             return ErrorNode(code=Codes.a)
 
     schema = strawberry.Schema(query=Query)
@@ -532,7 +532,7 @@ def test_generic_with_enum():
     @strawberry.type
     class Query:
         @strawberry.field
-        def estimated_value(self) -> Optional[EstimatedValue[int]]:
+        def estimated_value(self) -> EstimatedValue[int] | None:
             return EstimatedValue(value=1, type=EstimatedValueEnum.test)
 
     schema = strawberry.Schema(query=Query)
@@ -573,7 +573,7 @@ def test_supports_generic_in_unions_multiple_vars():
     @strawberry.type
     class Query:
         @strawberry.field
-        def example(self) -> Union[Fallback, Edge[int, str]]:
+        def example(self) -> Fallback | Edge[int, str]:
             return Edge(node="string", info=1)
 
     schema = strawberry.Schema(query=Query)
@@ -608,7 +608,7 @@ def test_supports_multiple_generics_in_union():
     @strawberry.type
     class Query:
         @strawberry.field
-        def example(self) -> list[Union[Edge[int], Edge[str]]]:
+        def example(self) -> list[Edge[int] | Edge[str]]:
             return [
                 Edge(cursor=strawberry.ID("1"), node=1),
                 Edge(cursor=strawberry.ID("2"), node="string"),
@@ -685,7 +685,7 @@ def test_generics_via_anonymous_union():
 
     @strawberry.type
     class Query:
-        entities: Connection[Union[Entity1, Entity2]]
+        entities: Connection[Entity1 | Entity2]
 
     schema = strawberry.Schema(query=Query)
 
@@ -777,7 +777,7 @@ def test_supports_lists_within_unions():
     @strawberry.type
     class Query:
         @strawberry.field
-        def user(self) -> Union[User, Edge[User]]:
+        def user(self) -> User | Edge[User]:
             return Edge(nodes=[User(name="P")])
 
     schema = strawberry.Schema(query=Query)
@@ -814,7 +814,7 @@ def test_supports_lists_within_unions_empty_list():
     @strawberry.type
     class Query:
         @strawberry.field
-        def user(self) -> Union[User, Edge[User]]:
+        def user(self) -> User | Edge[User]:
             return Edge(nodes=[])
 
     schema = strawberry.Schema(query=Query)
@@ -851,7 +851,7 @@ def test_raises_error_when_unable_to_find_type():
     @strawberry.type
     class Query:
         @strawberry.field
-        def user(self) -> Union[User, Edge[User]]:
+        def user(self) -> User | Edge[User]:
             return Edge(nodes=["bad example"])  # type: ignore
 
     schema = strawberry.Schema(query=Query)
@@ -985,7 +985,7 @@ def test_generic_extending_with_type_var():
     class Node(Generic[T]):
         id: strawberry.ID
 
-        def _resolve(self) -> Optional[T]:
+        def _resolve(self) -> T | None:
             return None
 
     @strawberry.type
@@ -1021,7 +1021,7 @@ def test_generic_extending_with_type_var():
 def test_self():
     @strawberry.interface
     class INode:
-        field: Optional[Self]
+        field: Self | None
         fields: list[Self]
 
     @strawberry.type
@@ -1138,7 +1138,7 @@ def test_generic_interface_extra_types():
         x: str = ""
 
     @strawberry.type
-    class Real(Generic[T], Abstract):
+    class Real(Abstract, Generic[T]):
         y: T
 
     @strawberry.type
@@ -1197,9 +1197,7 @@ def test_generic_with_interface():
     @strawberry.type
     class Query:
         @strawberry.field
-        def hello(
-            self, info: strawberry.Info
-        ) -> Union[Pagination[TestInterface], TestError]:
+        def hello(self, info: strawberry.Info) -> Pagination[TestInterface] | TestError:
             return Pagination(items=[Test1(data="test1")])
 
     schema = strawberry.Schema(Query, types=[Test1])
