@@ -1,15 +1,10 @@
 import enum
 import textwrap
-from typing import TYPE_CHECKING
-
-import pytest
+from typing import Annotated
 
 import strawberry
 from strawberry.printer import print_schema
 
-if TYPE_CHECKING:
-    import tests
-
 
 @strawberry.enum
 class LazyEnum(enum.Enum):
@@ -17,13 +12,11 @@ class LazyEnum(enum.Enum):
 
 
 def test_lazy_enum():
-    with pytest.deprecated_call():
-
-        @strawberry.type
-        class Query:
-            a: strawberry.LazyType[
-                "LazyEnum", "tests.schema.test_lazy_types.test_lazy_enums"
-            ]
+    @strawberry.type
+    class Query:
+        a: Annotated[
+            "LazyEnum", strawberry.lazy("tests.schema.test_lazy_types.test_lazy_enums")
+        ]
 
     expected = """
     enum LazyEnum {
