@@ -1,10 +1,8 @@
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Annotated
 
 import strawberry
 
 if TYPE_CHECKING:
-    import tests
-
     from .type_a import TypeA
 
 
@@ -13,7 +11,7 @@ class TypeB:
     @strawberry.field()
     def type_a(
         self,
-    ) -> strawberry.LazyType["TypeA", "tests.schema.test_lazy_types.type_a"]:
+    ) -> Annotated["TypeA", strawberry.lazy("tests.schema.test_lazy_types.type_a")]:
         from .type_a import TypeA
 
         return TypeA()
