@@ -1,7 +1,7 @@
 import textwrap
 from dataclasses import dataclass
 from textwrap import dedent
-from typing import Annotated, Generic, TypeVar, Union
+from typing import Annotated, Any, ClassVar, Generic, TypeVar, Union
 
 import pytest
 
@@ -599,6 +599,79 @@ def test_union_with_similar_nested_generic_types():
     assert result.data["containerB"]["items"][0]["b"] == 3
 
 
+def test_union_with_generic_uses_is_type_of_for_domain_objects():
+    T = TypeVar("T")
+
+    @dataclass
+    class SQLProduct:
+        name: str
+        price: float
+
+    @strawberry.type
+    class BaseGQLType:
+        __domain_type__: ClassVar[type | None] = None
+
+        @classmethod
+        def is_type_of(cls, obj: Any, _info) -> bool:
+            if (cls == obj.__class__) or (
+                cls.__domain_type__ and isinstance(obj, cls.__domain_type__)
+            ):
+                return True
+            return (
+                super().is_type_of(obj, _info)  # type: ignore[misc]
+                if hasattr(super(), "is_type_of")
+                else False
+            )
+
+    @strawberry.type
+    class Product(BaseGQLType):
+        __domain_type__: strawberry.Private[type | None] = SQLProduct
+
+        name: str
+        price: float
+
+    @strawberry.type
+    class Error(BaseGQLType):
+        message: str
+
+    @strawberry.type
+    class Page(BaseGQLType, Generic[T]):
+        items: list[T]
+
+    def get_products() -> Page[Product] | Error:
+        return Page[Product](items=[SQLProduct(name="a", price=2.2)])
+
+    @strawberry.type
+    class Query:
+        products: Page[Product] | Error = strawberry.field(resolver=get_products)
+
+    schema = strawberry.Schema(Query)
+    query = """
+    {
+        products {
+            __typename
+            ... on ProductPage {
+                items {
+                    name
+                    price
+                }
+            }
+            ... on Error {
+                message
+            }
+        }
+    }
+    """
+
+    result = schema.execute_sync(query)
+
+    assert not result.errors
+    assert result.data["products"] == {
+        "__typename": "ProductPage",
+        "items": [{"name": "a", "price": 2.2}],
+    }
+
+
 def test_lazy_union():
     """Previously this failed to evaluate generic parameters on lazy types"""
     TypeA = Annotated["TypeA", lazy("tests.schema.test_lazy_types.type_a")]
@@ -1244,3 +1317,55 @@ def test_union_used_inside_generic():
     """
         ).strip()
     )
+
+
+def test_annotated_union_inside_generic_subclass():
+    T = TypeVar("T")
+
+    @strawberry.type
+    class Dog:
+        name: str
+
+    @strawberry.type
+    class Cat:
+        name: str
+
+    DogCat = Annotated[Union[Dog, Cat], strawberry.union("DogCat")]
+
+    @strawberry.type
+    class Listing(Generic[T]):
+        items: list[T]
+
+    @strawberry.type
+    class Items(Listing[DogCat]):
+        pass
+
+    @strawberry.type
+    class Query:
+        @strawberry.field
+        def items(self) -> Items:
+            return Items(items=[Dog(name="Fido"), Cat(name="Whiskers")])
+
+    schema = strawberry.Schema(query=Query)
+
+    result = schema.execute_sync("""
+        {
+            items {
+                items {
+                    __typename
+                    ... on Dog { name }
+                    ... on Cat { name }
+                }
+            }
+        }
+    """)
+
+    assert not result.errors
+    assert result.data == {
+        "items": {
+            "items": [
+                {"__typename": "Dog", "name": "Fido"},
+                {"__typename": "Cat", "name": "Whiskers"},
+            ]
+        }
+    }
