@@ -1,9 +1,9 @@
 from inline_snapshot import snapshot
 
-from .utils.marks import requires_mypy, requires_pyright, skip_on_windows
+from .utils.marks import requires_mypy, requires_pyright, requires_ty, skip_on_windows
 from .utils.typecheck import Result, typecheck
 
-pytestmark = [skip_on_windows, requires_pyright, requires_mypy]
+pytestmark = [skip_on_windows, requires_pyright, requires_mypy, requires_ty]
 
 
 CODE = """
@@ -56,3 +56,25 @@ def test():
             ),
         ]
     )
+    assert results.ty == snapshot(
+        [
+            Result(
+                type="error",
+                message="No argument provided for required parameter `name`",
+                line=10,
+                column=1,
+            ),
+            Result(
+                type="error",
+                message="Too many positional arguments: expected 0, got 1",
+                line=10,
+                column=6,
+            ),
+            Result(
+                type="information",
+                message="Revealed type: `(self: User, *, name: str) -> None`",
+                line=12,
+                column=13,
+            ),
+        ]
+    )
